#include "Global.h"
#include "VDXMLAux.h"
#include "VDLogFactory.h"

Global* global = NULL;

Global::Global()
{
  load();
  initializeLog();
}

Global::~Global()
{
  save();
  finalizeLog();
}

void Global::load()
{
  xmlFile.loadFromFile();
  adapterIndex = SNOOP_INVALID_ADAPTER_INDEX;
}

void Global::save()
{
  xmlFile.saveToFile();
}

void Global::initializeLog()             
{
  VDXML* xml = xmlFile.root->gotoChild("Log");
  VDLog* log = VDLogFactory::createByXML(xml);

  if (log == NULL)
  {
    VDLogList* logList = new VDLogList;
    logList->items.add(VDLogFactory::createByURI("udp"));
    logList->items.add(VDLogFactory::createByURI("file://log/"));
    log = logList;
    VDLogFactory::save(log, xml);
    save();
  }
  VDLog::changeLog(log);
}

void Global::finalizeLog()
{
#ifndef VD_USE_CLASS_INITIALIZER
  VDLog::changeLog(NULL);
#endif  VD_USE_CLASS_INITIALIZER
}

bool Global::loadWindowPos(HWND hwnd, char* name)
{
  VDXML* xml = xmlFile.root->gotoChild("WindowPos")->gotoChild(name);
  return VDXMLAux::loadWindowPos(hwnd, xml); 
}

bool Global::saveWindowPos(HWND hwnd, char* name)
{
  VDXML* xml = xmlFile.root->gotoChild("WindowPos")->gotoChild(name);
  return VDXMLAux::saveWindowPos(hwnd, xml); 
}
